rnalysis.filtering.FoldChangeFilter.filter\_fold\_change\_direction
===================================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.filter_fold_change_direction